Square class

Constructors

Square({required Board board, required String name, required Option<Piece> piece})

Properties

board → Board
final
color → BoardColor
no setter
file → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
piece → Option<Piece>
final
rank → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
no setter
x → double
no setter
xAxis → int
no setter
y → double
no setter
yAxis → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited